"""Package handling ontologies."""

from .sbo import SBO
from .kisao import KISAO

# from .eco import ECO
# from .bto import BTO
# from .fma import FMA
# from .go import GO
